package com.example;

import javax.ws.rs.core.Response;

import org.apache.cxf.endpoint.Server;
import org.apache.cxf.jaxrs.client.JAXRSClientFactory;
import org.apache.cxf.jaxrs.client.WebClient;
import org.apache.cxf.jaxrs.spring.JAXRSServerFactoryBeanDefinitionParser.SpringJAXRSServerFactoryBean;
import org.apache.cxf.transport.local.LocalConduit;
import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(classes = { TestConfiguration.class })
public class SurveyApiTest {
	
	private static Server server;
	private com.example.SurveyApi api;
	
	@Autowired
	private SpringJAXRSServerFactoryBean serverFactory;

	@Before
	public void setup() throws Exception {
		server = serverFactory.create();
		api = JAXRSClientFactory.create(TestConfiguration.ENDPOINT_ADDRESS, com.example.SurveyApi.class, TestConfiguration.defaultProviders());
		WebClient.getConfig(api).getRequestContext().put(LocalConduit.DIRECT_DISPATCH, Boolean.TRUE);
	}
	
	@After
	public void destroy() throws Exception {
		server.stop();
		server.destroy();
	}
	
	@Test
	public void addGroupsTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.addGroups(surveyId);
		Assert.assertNotNull(response);
	}

	@Test
	public void addParticipantsTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.addParticipants(surveyId);
		Assert.assertNotNull(response);
		com.example.model.AddParticipants200Response result = response.readEntity(com.example.model.AddParticipants200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void closeSurveyTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.closeSurvey(surveyId);
		Assert.assertNotNull(response);
		com.example.model.SurveyDetails result = response.readEntity(com.example.model.SurveyDetails.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void createCustomQuestionTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;

		Response response = this.api.createCustomQuestion(surveyId, sectionId);
		Assert.assertNotNull(response);
		com.example.model.SurveySection result = response.readEntity(com.example.model.SurveySection.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void createPreviewTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.createPreview(surveyId);
		Assert.assertNotNull(response);
		com.example.model.CreatePreview200Response result = response.readEntity(com.example.model.CreatePreview200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void deleteSurveyTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.deleteSurvey(surveyId);
		Assert.assertNotNull(response);
	}

	@Test
	public void downloadReportTest() {
		java.util.UUID surveyId = null;
		java.lang.String token = null;
		java.lang.String frontend = null;

		Response response = this.api.downloadReport(surveyId, token, frontend);
		Assert.assertNotNull(response);
	}

	@Test
	public void getCustomSectionTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;

		Response response = this.api.getCustomSection(surveyId, sectionId);
		Assert.assertNotNull(response);
		com.example.model.SurveySection result = response.readEntity(com.example.model.SurveySection.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getFiltersTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.getFilters(surveyId);
		Assert.assertNotNull(response);
		com.example.model.GetFilters200Response result = response.readEntity(com.example.model.GetFilters200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getGroupsTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.getGroups(surveyId);
		Assert.assertNotNull(response);
		com.example.model.GetGroups200Response result = response.readEntity(com.example.model.GetGroups200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getParticipationsTest() {
		java.util.UUID surveyId = null;
		java.lang.String cursor = null;
		com.example.model.SortParticipants sort = null;
		java.util.List&lt;com.example.model.FilterSurveyParticipants&gt; filter = null;
		java.util.List&lt;java.util.UUID&gt; groups = null;

		Response response = this.api.getParticipations(surveyId, cursor, sort, filter, groups);
		Assert.assertNotNull(response);
		com.example.model.SurveyParticipationsResponse result = response.readEntity(com.example.model.SurveyParticipationsResponse.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getReportTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.getReport(surveyId);
		Assert.assertNotNull(response);
		com.example.model.GetReport200Response result = response.readEntity(com.example.model.GetReport200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getSurveyTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.getSurvey(surveyId);
		Assert.assertNotNull(response);
		com.example.model.SurveyDetails result = response.readEntity(com.example.model.SurveyDetails.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void openSurveyTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.openSurvey(surveyId);
		Assert.assertNotNull(response);
		com.example.model.SurveyDetails result = response.readEntity(com.example.model.SurveyDetails.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void patchSurveyTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.patchSurvey(surveyId);
		Assert.assertNotNull(response);
		com.example.model.SurveyDetails result = response.readEntity(com.example.model.SurveyDetails.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void patchSurveyReportTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.patchSurveyReport(surveyId);
		Assert.assertNotNull(response);
		com.example.model.PatchSurveyReport200Response result = response.readEntity(com.example.model.PatchSurveyReport200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void postRemindersTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.postReminders(surveyId);
		Assert.assertNotNull(response);
		com.example.model.PostReminders200Response result = response.readEntity(com.example.model.PostReminders200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void removeGroupsTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.removeGroups(surveyId);
		Assert.assertNotNull(response);
	}

	@Test
	public void removeParticipationsTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.removeParticipations(surveyId);
		Assert.assertNotNull(response);
	}

	@Test
	public void removeQuestionTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;
		java.util.UUID questionId = null;

		Response response = this.api.removeQuestion(surveyId, sectionId, questionId);
		Assert.assertNotNull(response);
	}

	@Test
	public void requestReportDownloadTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.requestReportDownload(surveyId);
		Assert.assertNotNull(response);
		com.example.model.RequestReportDownload200Response result = response.readEntity(com.example.model.RequestReportDownload200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void resetCustomSectionTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;

		Response response = this.api.resetCustomSection(surveyId, sectionId);
		Assert.assertNotNull(response);
		com.example.model.SurveySection result = response.readEntity(com.example.model.SurveySection.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void searchParticipationsTest() {
		java.util.UUID surveyId = null;
		java.lang.String query = null;
		java.lang.String cursor = null;
		com.example.model.SortParticipants sort = null;
		java.util.List&lt;com.example.model.FilterSurveyParticipants&gt; filter = null;
		java.util.List&lt;java.util.UUID&gt; groups = null;

		Response response = this.api.searchParticipations(surveyId, query, cursor, sort, filter, groups);
		Assert.assertNotNull(response);
		com.example.model.SurveyParticipationsResponse result = response.readEntity(com.example.model.SurveyParticipationsResponse.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void setCustomQuestionsTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;

		Response response = this.api.setCustomQuestions(surveyId, sectionId);
		Assert.assertNotNull(response);
		com.example.model.SurveySection result = response.readEntity(com.example.model.SurveySection.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void updateCustomQuestionTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;
		java.util.UUID questionId = null;

		Response response = this.api.updateCustomQuestion(surveyId, sectionId, questionId);
		Assert.assertNotNull(response);
		com.example.model.Question result = response.readEntity(com.example.model.Question.class);
		Assert.assertNotNull(result);
	}

}
